@@ -2165,7 +2165,12 @@ int GRSTx509CreateProxyRequest(char **reqtxt, char **keytxt, char *ocspurl)
   BIO_free(reqmem);
 
   X509_REQ_free(certreq);
-  
+  EVP_PKEY_free(pkey);
+  if (ent)
+      X509_NAME_ENTRY_free(ent);
+  if (subject)
+      X509_NAME_free(subject);
+
   return 0;
 }
 
@@ -2267,6 +2272,11 @@ int GRSTx509MakeProxyRequest(char **reqtxt, char *proxydir,
   BIO_free(reqmem);
 
   X509_REQ_free(certreq);
+  EVP_PKEY_free(pkey);
+  if (ent)
+      X509_NAME_ENTRY_free(ent);
+  if (subject)
+      X509_NAME_free(subject);
   
   return 0;
 }
