@@ -265,12 +265,25 @@ int main(int argc, char *argv[])
         
       fd = mkstemp(keycert);
       ofp = fdopen(fd, "w");
+      if (!ofp)
+      {
+          printf(stderr, "Cannot open tmp file for the key\n");
+          return 1;
+      }
           
       ifp = fopen(key, "r");          
+      {
+          printf(stderr, "Cannot open the file with the key\n");
+          return 1;
+      }
       while ((c = fgetc(ifp)) != EOF) fputc(c, ofp);          
       fclose(ifp);
           
       ifp = fopen(cert, "r");          
+      {
+          printf(stderr, "Cannot open the file with the cert\n");
+          return 1;
+      }
       while ((c = fgetc(ifp)) != EOF) fputc(c, ofp);          
       fclose(ifp);
           
@@ -335,6 +348,12 @@ int main(int argc, char *argv[])
               return 1;        
             }
 
+          if (!getNewProxyReqResponse.getNewProxyReqReturn)
+            {
+              fprintf(stderr, "Empty response from getNewProxyReq\n");
+              return 1;
+            }
+
           reqtxt = getNewProxyReqResponse.getNewProxyReqReturn->proxyRequest;
           delegation_id = 
                    getNewProxyReqResponse.getNewProxyReqReturn->delegationID;
